package com.xuqm.server.appmanager.controller.manager.v1;

import com.xuqm.server.appmanager.common.CommonHelper;
import com.xuqm.server.appmanager.common.JWTHelper;
import com.xuqm.server.appmanager.common.TimeHelper;
import com.xuqm.server.appmanager.entitys.UserInfo;
import com.xuqm.server.appmanager.entitys.sys.v1.ApplicationEntity;
import com.xuqm.server.appmanager.http.HttpResult;
import com.xuqm.server.appmanager.repository.sys.v1.ApplicationRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Random;

@RestController
@RequestMapping("manager/v1")
public class ManagerV1Controller {

    @Autowired
    private ApplicationRepository applicationRepository;

    @PostMapping("/manager/create")
    public HttpResult<String> appCreate(@RequestBody ApplicationEntity application, @RequestHeader(name = "token") String token) throws Exception {
        if (null == application.getAppName() || null == application.getPackageName()) {
            return new HttpResult<>(201, "参数错误", null);
        } else {
            UserInfo userInfo = JWTHelper.getUser(token);
            if (null == userInfo) {
                return new HttpResult<>(401, "登录失效", null);
            }
            ApplicationEntity app = applicationRepository.findFirstByAppNameAndTenantNo(application.getAppName(), userInfo.getTenantNo());
            if (null != app) return new HttpResult<>(201, "已创建相关类型的同名应用", null);
            app = new ApplicationEntity();
            app.setTenantNo(userInfo.getTenantNo());
            app.setAppName(application.getAppName());
            app.setPackageName(application.getPackageName());
            app.setDownloadUrl(application.getDownloadUrl());
            app.setAppId(CommonHelper.getRandomId());
            applicationRepository.save(app);

            return new HttpResult<>(200, "创建成功", app.getAppId());
        }

    }

    @PostMapping("/manager/list")
    public HttpResult<List<ApplicationEntity>> appList(@RequestBody ApplicationEntity application, @RequestHeader(name = "token") String token) throws Exception {

        UserInfo userInfo = JWTHelper.getUser(token);
        if (null == userInfo) {
            return new HttpResult<>(401, "登录失效", null);
        }


        List<ApplicationEntity> apps = applicationRepository.findAllByTenantNo(userInfo.getTenantNo());

        return new HttpResult<>(200, "成功", apps);
    }

}
